{
    "scan": {
        "analyzer-version-clippy": "1.96.0",
        "analyzer-version-cppcheck": "2.21.0",
        "analyzer-version-gcc": "16.1.1",
        "analyzer-version-gcc-analyzer": "16.1.1",
        "analyzer-version-shellcheck": "0.11.0",
        "analyzer-version-unicontrol": "0.0.2",
        "enabled-plugins": "clippy, cppcheck, gcc, shellcheck, unicontrol",
        "exit-code": 0,
        "host": "ip-172-16-1-94.us-west-2.compute.internal",
        "known-false-positives": "/usr/share/csmock/known-false-positives.js",
        "known-false-positives-rpm": "known-false-positives-0.0.0.20260524.213755.g3c6d0be.main-1.el9.noarch",
        "mock-config": "fedora-rawhide-x86_64",
        "project-name": "python-scikit-build-0.19.0-1",
        "store-results-to": "/tmp/tmp058mvxna/python-scikit-build-0.19.0-1.tar.xz",
        "time-created": "2026-06-22 18:26:32",
        "time-finished": "2026-06-22 18:28:11",
        "tool": "csmock",
        "tool-args": "'/usr/bin/csmock' '-r' 'fedora-rawhide-x86_64' '-t' 'unicontrol,shellcheck,gcc,clippy,cppcheck' '-o' '/tmp/tmp058mvxna/python-scikit-build-0.19.0-1.tar.xz' '--gcc-analyze' '--unicontrol-notests' '--unicontrol-bidi-only' '--install' 'pam' '/tmp/tmp058mvxna/python-scikit-build-0.19.0-1.src.rpm'",
        "tool-version": "csmock-3.8.6.20260622.142223.gdf61adf-1.el9"
    },
    "defects": []
}
